Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1435)

Unified Diff: content/browser/push_messaging/push_messaging_message_filter.h

Issue 1134733006: Push API: use (un)subscription instead of (un)registration (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed pre-submit warning Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/push_messaging/push_messaging_message_filter.h
diff --git a/content/browser/push_messaging/push_messaging_message_filter.h b/content/browser/push_messaging/push_messaging_message_filter.h
index afd8d6743a47550fb68984286bbc2955cd54fe11..9dc6f9c660dedf6d0e32306ef4cd2fe379fba245 100644
--- a/content/browser/push_messaging/push_messaging_message_filter.h
+++ b/content/browser/push_messaging/push_messaging_message_filter.h
@@ -45,17 +45,17 @@ class PushMessagingMessageFilter : public BrowserMessageFilter {
void OnDestruct() const override;
bool OnMessageReceived(const IPC::Message& message) override;
- // Register methods on IO thread ---------------------------------------------
+ // Subscribe methods on IO thread --------------------------------------------
- void OnRegisterFromDocument(int render_frame_id,
- int request_id,
- const std::string& sender_id,
- bool user_visible,
- int64_t service_worker_registration_id);
+ void OnSubscribeFromDocument(int render_frame_id,
+ int request_id,
+ const std::string& sender_id,
+ bool user_visible,
+ int64_t service_worker_registration_id);
- void OnRegisterFromWorker(int request_id,
- int64_t service_worker_registration_id,
- bool user_visible);
+ void OnSubscribeFromWorker(int request_id,
+ int64_t service_worker_registration_id,
+ bool user_visible);
void DidPersistSenderId(const RegisterData& data,
const std::string& sender_id,
@@ -94,18 +94,18 @@ class PushMessagingMessageFilter : public BrowserMessageFilter {
PushRegistrationStatus status,
const std::string& push_registration_id);
- // Unregister methods on IO thread -------------------------------------------
+ // Unsubscribe methods on IO thread ------------------------------------------
- void OnUnregister(int request_id, int64_t service_worker_registration_id);
+ void OnUnsubscribe(int request_id, int64_t service_worker_registration_id);
- void UnregisterHavingGottenPushRegistrationId(
+ void UnsubscribeHavingGottenPushSubscriptionId(
int request_id,
int64_t service_worker_registration_id,
const GURL& requesting_origin,
- const std::string& push_registration_id,
+ const std::string& push_subscription_id,
ServiceWorkerStatusCode service_worker_status);
- void UnregisterHavingGottenSenderId(
+ void UnsubscribeHavingGottenSenderId(
int request_id,
int64_t service_worker_registration_id,
const GURL& requesting_origin,

Powered by Google App Engine
This is Rietveld 408576698